@@ -70,6 +70,7 @@ MI.quantile <- function(imp.model, L, data)
 
 MREst.quantile <- function(response, tau, imp.model, mis.model, moment, order, L, data)
 {
+  if (response == "R") stop("variable name 'R' is reserved for the missingness indicator; please change the variable 'R' in the data set to a different name")
   resp <- data[ , response]
   if (!is.numeric(resp)) stop("response variable is not numeric")
   if (all(!is.na(resp))){
@@ -90,6 +91,7 @@ MREst.quantile <- function(response, tau, imp.model, mis.model, moment, order, L
     # names of the auxiliary variables
     aux.names <- ext.names(reg.model = imp.model, mis.model = mis.model)
     aux.names <- unique(c(aux.names, moment))
+	if (any(aux.names == "R")) stop("variable name 'R' is reserved for the missingness indicator; please change the variable 'R' in the data set to a different name")
     if (any(is.na(data[ , aux.names]))) stop("auxiliary variables being used need to be fully observed")
     data.sub <- data[ , c(response, aux.names)]
     data.sub$R <- 1 * !is.na(resp) # missingness indicator
@@ -157,13 +159,13 @@ MREst.quantile <- function(response, tau, imp.model, mis.model, moment, order, L
 #' \code{MR.quantile()} is used to estimate the marginal quantile of a variable which is subject to missingness. Multiple missingness probability models and imputation models are allowed.
 #' @param response The response variable of interest whose marginal quantile is to be estimated.
 #' @param tau A numeric value in (0,1). The quantile to be estimated.
-#' @param imp.model A list of imputation models defined by \code{\link{def.glm}}.
-#' @param mis.model A list of missingness probability models defined by \code{\link{def.glm}}. The dependent variable is always specified as \code{R}.
+#' @param imp.model A list of imputation models defined by \code{\link{glm.work}}.
+#' @param mis.model A list of missingness probability models defined by \code{\link{glm.work}}. The dependent variable is always specified as \code{R}.
 #' @param moment A vector of auxiliary variables whose moments are to be calibrated.
-#' @param order A numeric value. The order of moments to be calibrated.
+#' @param order A numeric value. The order of moments up to which to be calibrated.
 #' @param L Number of imputations.
 #' @param data A data frame with missing data encoded as \code{NA}.
-#' @param bootstrap Logical. Should a bootstrap method be applied to calculate the standard error of the estimator and construct a Wald confidence interval for the estimated marginal quantile.
+#' @param bootstrap Logical. If \code{bootstrap = TRUE}, the bootstrap will be applied to calculate the standard error and construct a Wald confidence interval.
 #' @param bootstrap.size A numeric value. Number of bootstrap resamples generated if \code{bootstrap = TRUE}.
 #' @param alpha Significance level used to construct the 100(1 - \code{alpha})\% Wald confidence interval.
 #' @import stats
@@ -189,17 +191,17 @@ MREst.quantile <- function(response, tau, imp.model, mis.model, moment, order, L
 #' dat[R == 0, 2] <- NA
 #'
 #' # Define the outcome regression models and missingness probability models
-#' imp1 <- def.glm(formula = Y ~ X + exp(X), family = gaussian)
-#' imp2 <- def.glm(formula = Y ~ X + I(X ^ 2), family = gaussian)
-#' mis1 <- def.glm(formula = R ~ X + I(X ^ 2), family = binomial(link = logit))
-#' mis2 <- def.glm(formula = R ~ X + exp(X), family = binomial(link = cloglog))
+#' imp1 <- glm.work(formula = Y ~ X + exp(X), family = gaussian)
+#' imp2 <- glm.work(formula = Y ~ X + I(X ^ 2), family = gaussian)
+#' mis1 <- glm.work(formula = R ~ X + I(X ^ 2), family = binomial(link = logit))
+#' mis2 <- glm.work(formula = R ~ X + exp(X), family = binomial(link = cloglog))
 #' MR.quantile(response = Y, tau = 0.25, imp.model = list(imp1, imp2),
 #'             mis.model = list(mis1, mis2), L = 10, data = dat)
 #' MR.quantile(response = Y, tau = 0.25, moment = c(X), order = 2, data = dat)
 #' @export
 
 MR.quantile <- function(response, tau = 0.5, imp.model = NULL, mis.model = NULL, moment = NULL, order = 1, 
-                        L = 30, data, bootstrap = FALSE, bootstrap.size = 500, alpha = 0.05)
+                        L = 30, data, bootstrap = FALSE, bootstrap.size = 300, alpha = 0.05)
 {
   if(!requireNamespace("quantreg", quietly = TRUE))
     stop("need CRAN package 'quantreg' for quantile estimation")
@@ -207,6 +209,7 @@ MR.quantile <- function(response, tau = 0.5, imp.model = NULL, mis.model = NULL,
   if (!is.null(moment)) moment <- as.character(substitute(moment))[-1]
   est.ls <- MREst.quantile(response = response, tau = tau, imp.model = imp.model, mis.model = mis.model, moment = moment, order = order, L = L, data = data)
   est <- est.ls$estimate
+  names(est) <- paste(tau*100,"% quantile",sep="")
   
   # Bootstrap method for variance estimation
   if (bootstrap == TRUE){
@@ -223,6 +226,9 @@ MR.quantile <- function(response, tau = 0.5, imp.model = NULL, mis.model = NULL,
     se <- sd(bs.est) # bootstrap standard error
     cilb <- est - qnorm(1 - alpha / 2) * se
     ciub <- est + qnorm(1 - alpha / 2) * se
+	names(cilb) <- "lower bound"
+	names(ciub) <- "upper bound"
+	
     if (is.null(imp.model) & is.null(mis.model) & is.null(moment)) return(list(q = est, SE = se, CI = c(cilb, ciub)) )
     else return(list(q = est, SE = se, CI = c(cilb, ciub), weights = est.ls$weights))
   } else {
